@@ -1,10 +1,10 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM USPK08
 
       PARAMETER(N=200)
-      CHARACTER CSGI*1
+      CHARACTER USGI*3
       REAL T(N), Z(N)
       LOGICAL LSFNT
       DOUBLE PRECISION R, A
@@ -35,7 +35,7 @@
       CALL USCSET('CXSIDE'  , 'T')
       CALL USCSET('CYSIDE'  , 'L')
       CALL SWLGET('SYSFONT',LSFNT)
-      CALL USSTTL('TEMPERATURE', '\^'//CSGI(4)//'C', 'DEPTH', 'm')
+      CALL USSTTL('TEMPERATURE', '\^'//USGI(228)//'C', 'DEPTH', 'm')
       CALL USGRPH(N, T, Z)
 
       CALL GRCLS
