@@ -3,6 +3,7 @@
 
       REAL      RPX(*),RPY(*)
       LOGICAL   LFCATR
+      INTEGER   ITPATX
 
       CALL SWQFCC(LFCATR)
       IF(.NOT.LFCATR) THEN
@@ -24,7 +25,8 @@
       CALL SWSTCL(ICOLOR)
       CALL SWSLCL(ICOLOR)
 
-      CALL SZTNOP(ITPAT)
+      ITPATX=999*1000+MOD(ITPAT,1000)
+      CALL SZTNOP(ITPATX)
       CALL SZTNZR(N,RPX,RPY)
       CALL SZTNCL
 
