@@ -3,6 +3,7 @@
 
       REAL      UPX(*),UPY(*)
       LOGICAL   LFCATR
+      INTEGER    ITPATX
 
       CALL SWQFCC(LFCATR)
       IF(.NOT.LFCATR) THEN
@@ -24,7 +25,9 @@
       CALL SWSTCL(ICOLOR)
       CALL SWSLCL(ICOLOR)
 
-      CALL SZTNOP(ITPAT)
+
+      ITPATX=999*1000+MOD(ITPAT,1000)
+      CALL SZTNOP(ITPATX)
       CALL SZTNZU(N,UPX,UPY)
       CALL SZTNCL
 
