@@ -136,6 +136,9 @@ static double dlnscale;
 static double offx = 0.0;
 static double offy = 0.0;
 
+/* Tone Color (Full Color)*/
+static double rt2,gt2,bt2;
+
 /* For BITMAP Image */
 static unsigned char * pixels;
 static int rows;
@@ -2121,14 +2124,20 @@ void ZGGTON(DCL_INT *np, DCL_REAL wpx[], DCL_REAL wpy[], DCL_INT *itpat)
 
   //  ibit = *itpat % 1000;
   iclr = (*itpat / 1000) % MAXCLI;
-  if ((*itpat / 1000) == 999){ iclr=0;}
-  rt1 = (double) cx[iclr].red   / 65535;
-  gt1 = (double) cx[iclr].green / 65535;
-  bt1 = (double) cx[iclr].blue  / 65535;
+
+  if ((*itpat / 1000) == 999){
+    rt1=rt2;
+    gt1=gt2;
+    bt1=bt2;
+  }else{
+    rt1 = (double) cx[iclr].red   / 65535;
+    gt1 = (double) cx[iclr].green / 65535;
+    bt1 = (double) cx[iclr].blue  / 65535;
+  }
 
   cairo_set_source_rgb(crb,rt1,gt1,bt1);
-  cairo_rectangle(crb,0.0,0.0,16.0,16.0);
   cairo_fill(crb);
+  cairo_rectangle(crb,0.0,0.0,16.0,16.0);
 
   pattern = cairo_pattern_create_for_surface (csb);
   cairo_pattern_set_extend (pattern , CAIRO_EXTEND_REPEAT);
@@ -2152,7 +2161,9 @@ void ZGGTON(DCL_INT *np, DCL_REAL wpx[], DCL_REAL wpy[], DCL_INT *itpat)
   }
 
   cairo_close_path(cr);
+
   cairo_set_source_rgb(cr,rt1,gt1,bt1);
+
 // Adhoc Patch for 3
   if ( idev_type == IWS_FILE && ifl == IFL_PDF ){
     cairo_fill_preserve(cr);
@@ -2403,11 +2414,8 @@ void zgstcl_(DCL_INT *icolor)
 void ZGSTCL(DCL_INT *icolor)
 #endif
 {
-  /*This Function is not used in uipk samples
-     So, it is not tested.*/
   /* set tone color in 24 bit RGB */
   GdkColor  loccx;
-  double rt1,gt1,bt1;
 
   if (ltfrst) {
 //    gct = gdk_gc_new (drawing_area->window);
@@ -2419,11 +2427,10 @@ void ZGSTCL(DCL_INT *icolor)
   loccx.green = ((*icolor >> 8)  & 255) * 256;
   loccx.blue  = ((*icolor >> 0)  & 255) * 256;
 
-  rt1 = (double) loccx.red   / 65535;
-  gt1 = (double) loccx.green / 65535;
-  bt1 = (double) loccx.blue  / 65535;
+  rt2 = (double) loccx.red   / 65535;
+  gt2 = (double) loccx.green / 65535;
+  bt2 = (double) loccx.blue  / 65535;
 
-  cairo_set_source_rgb(cr,rt1,gt1,bt1);
 }
 
 #ifndef WINDOWS
