@@ -1,5 +1,5 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE ULXLOG ( CSIDE, NLBL, NTICKS )
 
@@ -9,7 +9,7 @@
 
       PARAMETER(MAXL=50,MAXS=200)
       DIMENSION BL(10),BS(10),UX1(MAXS),UX2(MAXL),UXT(MAXL)
-      CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CSGI,CSIDE,CHW*16
+      CHARACTER CH(MAXL)*18,CHR*8,CFMT*16,USGI*3,CSIDE,CHW*16
       LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUXCHK,LOFF,LSFNT
 
       SAVE
@@ -98,12 +98,13 @@
         IF(NBL.GT.MAXL) CALL MSGDMP('E', 'ULXLOG', 'TOO MANY LABELS.')
         UX2(NBL)=SGN*BL(IB)*10.**IP
 
+
         IF(ITYPE.LE.2) THEN
           IF(JTYPE.EQ.0 .AND. IB.NE.1) THEN
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
           ELSE
             IF(JTYPE.EQ.1 .AND. NB.NE.1) THEN
-              WRITE(CH(NBL),'(I1,A1)') INT(BL(IB)), CSGI(IXCHR)
+              WRITE(CH(NBL),'(I1,A3)') INT(BL(IB)), USGI(IXCHR)
             ELSE
               CH(NBL)=' '
             ENDIF
@@ -112,14 +113,14 @@
             CALL CLADJ(CHR)
             IF(LCNTL) THEN
 *              IF(LSFNT) THEN
-                CH(NBL)(3:16)='10'//'\^{'//CHR(1:LENZ(CHR))
+                CH(NBL)(5:18)='10'//'\^{'//CHR(1:LENZ(CHR))
      +            //'}'
 *              ELSE
 *                CH(NBL)(3:16)='1x'//CSGI(ISUP)//CHR(1:LENZ(CHR))
 *     +            //CSGI(IRST)
 *              END IF
             ELSE
-              CH(NBL)(2:16)='E'//CHR
+              CH(NBL)(4:18)='E'//CHR
             ENDIF
             CALL CLADJ(CH(NBL))
           END IF
