@@ -1,5 +1,5 @@
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE ULYLOG ( CSIDE, NLBL, NTICKS )
 
@@ -9,7 +9,7 @@
 
       PARAMETER(MAXL=50,MAXS=200)
       DIMENSION BL(10),BS(10),UY1(MAXS),UY2(MAXL),UYT(MAXL)
-      CHARACTER CH(MAXL)*16,CHR*8,CFMT*16,CSGI,CSIDE,CHW*16
+      CHARACTER CH(MAXL)*18,CHR*8,CFMT*16,CSGI*3,CSIDE,CHW*16
       LOGICAL LRLT,LRGT,LABEL,LEPSL,LCNTL,LUYCHK,LOFF,LSFNT
 
       SAVE
@@ -103,7 +103,7 @@
             WRITE(CH(NBL),'(I1)') INT(BL(IB))
           ELSE
             IF(JTYPE.EQ.1 .AND. NB.NE.1) THEN
-              WRITE(CH(NBL),'(I1,A1)') INT(BL(IB)), CSGI(IYCHR)
+              WRITE(CH(NBL),'(I1,A3)') INT(BL(IB)), USGI(IYCHR)
             ELSE
               CH(NBL)=' '
             ENDIF
@@ -112,14 +112,14 @@
             CALL CLADJ(CHR)
             IF(LCNTL) THEN
 *              IF(LSFNT) THEN
-                CH(NBL)(3:16)='10'//'\^{'//CHR(1:LENZ(CHR))
+                CH(NBL)(5:18)='10'//'\^{'//CHR(1:LENZ(CHR))
      +            //'}'
 *              ELSE
 *                CH(NBL)(3:16)='10'//CSGI(ISUP)//CHR(1:LENZ(CHR))
 *     +            //CSGI(IRST)
 *              END IF
             ELSE
-              CH(NBL)(2:16)='E'//CHR
+              CH(NBL)(4:18)='E'//CHR
             ENDIF
             CALL CLADJ(CH(NBL))
           ENDIF
